@@ -8,9 +8,13 @@
 #' @importFrom car recode
 #' @export
 #' @examples
-#' tadaa_likertize(x = runif(100, 0, 10), classes = 3, method = "quantiles")
-#' tadaa_likertize(x = runif(100, 0, 10), classes = 3, method = "meansd")
-tadaa_likertize <- function(x, classes = 3, method = "quantiles"){
+#' \dontrun{
+#' likertize(x = runif(100, 0, 10), classes = 3, method = "quantiles")
+#' likertize(x = runif(100, 0, 10), classes = 3, method = "meansd")
+#' }
+likertize <- function(x, classes = 3, method = "quantiles"){
+
+  .Deprecated("You probably want to use sjmisc::split_var")
 
   if (classes == 3) {
     if (method == "quantiles") {
@@ -31,6 +35,14 @@ tadaa_likertize <- function(x, classes = 3, method = "quantiles"){
   }
 }
 
+#' @rdname likertize
+#' @inheritParams likertize
+#' @export
+tadaa_likertize <- function(x, classes = 3, method = "quantiles") {
+  .Deprecated("It's called likertize() now, but you probably want to use sjmisc::split_var")
+  likertize(x, classes, method)
+}
+
 #' Convenience functions for interval recodes
 #'
 #' Get recode assigments for even intervals of discrete numeric values compatible
